@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.org>
 # 	   
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,10 +23,14 @@
 # Extension module for BibTeX files
 
 import _bibtex
-import os, sys, tempfile, pwd, time, traceback, re, string, copy
+import re
+import string
+import copy
 
-from types import *
-from Pyblio.Fields import *
+from gettext import gettext as _
+
+from Pyblio.Fields import Author, AuthorGroup, Date, LongText
+from Pyblio.Fields import Reference, Text, URL
 from Pyblio import Base, Config, Autoload, Types
 from Pyblio import Open, Key, Utils, Iterator, Exceptions
 
@@ -320,12 +325,11 @@ class DataBase(Base.DataBase):
 	    valid = re.compile('^\w+$')
 	    for k in user.keys():
 		if not valid.match(k):
-		    raise TypeError, _("key `%s' is malformed") % k
+		    raise TypeError, _(u"key “%s” is malformed") % k
 		_bibtex.set_string(self.parser, k,
                                    _bibtex.reverse(_base_fieldtype[Text],
                                                    Config.get('bibtex+/braces').data,
                                                    user [k][0]))
-	finished = 0
 	errors = []
 
 	# Creer la base de cles
@@ -337,7 +341,7 @@ class DataBase(Base.DataBase):
                     self.add(entry)
                 else:
                     if self.dict.has_key(entry.key):
-                        errors.append(_("%s:%d: key `%s' already defined") % (
+                        errors.append(_(u"%s:%d: key “%s” already defined") % (
                             str(self.key), entry.line, entry.key.key))
                     else:
                         self.dict [entry.key] = entry
@@ -356,7 +360,7 @@ class DataBase(Base.DataBase):
                 self.add(entry)
             else:
                 if self.dict.has_key(entry.key):
-                    errors.append(_("%s:%d: key `%s' already defined") % (
+                    errors.append(_(u"%s:%d: key “%s” already defined") % (
                         repr(self.key), entry.line, repr(entry.key.key)))
                 else:
                     self.dict[entry.key] = entry
@@ -368,7 +372,7 @@ class DataBase(Base.DataBase):
 	    valid = re.compile('^\w+$')
 	    for k in user.keys():
 		if not valid.match(k):
-		    raise TypeError, _("key `%s' is malformed") % k
+		    raise TypeError, _(u"key “%s” is malformed") % k
 		_bibtex.set_string(self.parser, k,
                                    _bibtex.reverse(_base_fieldtype[Text],
                                                    Config.get('bibtex+/braces').data,
