@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.org>
 # 	   
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,41 +23,39 @@
 # TO DO:
 # List view troubles
 
-import gobject, gtk, gtk.glade
-import gnome.ui 
+import copy
+import re
+import string
+import gobject
+import gtk
 
-import copy, os.path, re, string   
+from gettext import gettext as _
 
 from Pyblio.GnomeUI import Utils
-from Pyblio import Config, version
-from Pyblio.Utils import format
+from Pyblio import Config
 
 _map = string.maketrans ('\t\n', '  ')
 _cpt = re.compile ('\s+')
 
-class ConfigDialog (Utils.GladeWindow):
 
+class ConfigDialog (Utils.Builder):
     gladeinfo = {
-        'file': 'config1.glade',
-        'root': 'config1',
+        'file': 'config.ui',
+        'root': 'config',
         'name': 'configuration'
         }
 
-    def __init__ (self, parent = None):
+    def __init__(self, parent=None):
+        Utils.Builder.__init__(self, parent, window='config')
 
-        Utils.GladeWindow.__init__ (self, parent, window = 'config1')
-
-        self.dialog = self.xml.get_widget ('config1')
-        content = self.xml.get_widget ('dialog-vbox1')
+        self.dialog = self.xml.get_object('config')
+        content = self.xml.get_object('dialog-vbox1')
 
         self.w = gtk.Notebook ()
 
         content.pack_start (self.w)
 
-##      tooltips = gtk.Tooltips ()
-##      tooltips.enable ()
-        
-        self.warning = 0
+        self.warning = False
         self.parent = parent
         
         domains = Config.domains ()
@@ -105,10 +104,6 @@ class ConfigDialog (Utils.GladeWindow):
                 
                 cw [item] = edit
                 hbox.pack_start (edit.w, False)
-
-
-##                     tooltips.set_tip (button, desc)
-
                 table.pack_start (hbox,
                                   expand = edit.resize,
                                   fill   = edit.resize)
@@ -129,23 +124,16 @@ class ConfigDialog (Utils.GladeWindow):
     def on_close1 (self, w):
 
         self.size_save ()
-        self.dialog.hide_all()
+        self.dialog.hide()
 
     def show (self):
         self.dialog.show_all()
         
-    def display_help (self, w, data):
-        (w, help) = data
-        d = gnome.ui.OkDialog (format (help, 40, 0, 0), w)
-        d.show_all ()
-        return
-        
     def changed (self):
         if not self.warning:
-            self.warning = 1
-            self.parent.warning (
-                _("Some changes require to restart Pybliographic\n"
-                  "to be correctly taken into account"))
+            self.warning = True
+            Utils.warning_dialog_s(self.parent, _("Some changes require to restart Pybliographic\n"
+                                   "to be correctly taken into account"))
 
 
 class BaseConfig:
