@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of pybliographer
-# 
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
+#
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.org>
 # 	   
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,30 +23,29 @@
 
 ''' This module defines a Document class '''
 
+import os
+import string
+import types
+import sys
+import traceback
+import stat
+import cPickle as pickle
 import gobject
-
-from gnome import ui
-
-import gnome
 import gtk
-import gtk.glade
 
-from gtk import gdk
+from gettext import gettext as _
 
 from Pyblio.GnomeUI import Editor, Entry, FileSelector, Format
 from Pyblio.GnomeUI import Index, OpenURL, Search, Utils
 from Pyblio.GnomeUI.Sort import SortDialog
 from Pyblio.GnomeUI.Medline import MedlineUI
 
-from Pyblio import Base, Config, Connector, Exceptions, Fields, Open
-from Pyblio import Query, Resource, Selection, Sort, Types, version
+from Pyblio import Config, Connector, Exceptions, Fields, Open
+from Pyblio import Query, Resource, Selection, Sort, version
 from Pyblio import Search as SearchCls
 
 import Pyblio.Style.Utils
 
-import os, string, copy, types, sys, traceback, stat
-
-import cPickle as pickle
 
 printable = string.lowercase + string.uppercase + string.digits
 
@@ -152,14 +151,14 @@ class Document (Connector.Publisher):
             
             ('New',  gtk.STOCK_NEW,   None,         None,   None,     self.new_document),
             ('Open', gtk.STOCK_OPEN,  None,         None,   _('Open a file'), self.ui_open_document),
-            ('Open_URL', None, _('Open _Location'), '<control>l',   None, self.ui_open_location),
+            ('Open_URL', None, _(u'Open _Location…'), '<control>l',   None, self.ui_open_location),
             ('Save', gtk.STOCK_SAVE,  None,         None,   _('Save the current file'), self.save_document),
             ('Save_As', gtk.STOCK_SAVE_AS,  None,         None,   None,     self.save_document_as),
             ('Close', gtk.STOCK_CLOSE,  None,         None,   None,     self.close_document),
             ('Quit', gtk.STOCK_QUIT,  None,         None,   None,     self.exit_application),
 
-            ('Merge',   None, _('Merge With...'),    '<control>g',  None, self.merge_database),
-            ('Medline', None, _('Medline Query...'), '<control>m',  None, self.query_database),
+            ('Merge',   None, _(u'Merge With…'),    '<control>g',  None, self.merge_database),
+            ('Medline', None, _(u'Medline Query…'), '<control>m',  None, self.query_database),
 
 
 
@@ -172,11 +171,11 @@ class Document (Connector.Publisher):
             ('Delete', gtk.STOCK_DELETE,  None,         None,   None,     self.delete_entry),
             ('Find', gtk.STOCK_FIND,  None,         None,   None,     self.find_entries),
             
-            ('Sort', None, _('S_ort...'), None,  None, self.sort_entries),
-            ('Cite', gtk.STOCK_JUMP_TO,   _('Cite...'), None,  _('Cite key(s)'), self.lyx_cite),
-            ('Format', gtk.STOCK_EXECUTE, _('Format...'), None,  None, self.format_entries),
+            ('Sort', None, _(u'S_ort…'), None,  None, self.sort_entries),
+            ('Cite', gtk.STOCK_JUMP_TO,   _(u'Cite…'), None,  _('Cite key(s)'), self.lyx_cite),
+            ('Format', gtk.STOCK_EXECUTE, _(u'Format…'), None,  None, self.format_entries),
 
-            ('Fields', None, _('Fields...'), None,  None, self.set_fields),
+            ('Fields', None, _(u'Fields…'), None,  None, self.set_fields),
             ('Preferences', gtk.STOCK_PREFERENCES,  None,         None,   None,     self.set_preferences),
             ('Forget', None, _('Forget all changes'),     None,   None,     self.forget_changes_cb),
             
@@ -198,49 +197,41 @@ class Document (Connector.Publisher):
 
         self.uim.ensure_update ()
 
-        gp = os.path.join(Utils.glade_root, 'pyblio.glade')
-        
-        self.xml = gtk.glade.XML (gp, 'main', domain = 'pybliographer')
-        self.xml.signal_autoconnect (self)
+        gp = os.path.join(Utils.glade_root, 'pyblio.ui')
+        icon_file = os.path.join (version.pixmapsdir, 'pybliographic.png')
 
-        self.w = self.xml.get_widget ('main')
-        self.paned = self.xml.get_widget ('main_pane')
+        self.xml = gtk.Builder()
+        self.xml.set_translation_domain('pybliographer')
+        self.xml.add_from_file(gp)
+        self.xml.connect_signals(self)
 
-        self.w.set_menus (self.uim.get_widget ('/Menubar'))
-        self.w.set_toolbar (self.uim.get_widget ('/Toolbar'))
+        self.w = self.xml.get_object('main')
+        self.w.set_icon_from_file(icon_file)
+        self.paned = self.xml.get_object('main_pane')
+
+        box = self.xml.get_object('table')
+        menubar = (self.uim.get_widget ('/Menubar'))
+        toolbar = (self.uim.get_widget ('/Toolbar'))
+        box.attach(menubar, 0, 1, 0, 1, yoptions=0)
+        box.attach(toolbar, 0, 1, 1, 2, yoptions=0)
 
         self.w.add_accel_group (self.uim.get_accel_group ())
 
-        self.w.add_events (gdk.KEY_PRESS_MASK)
+        self.w.add_events (gtk.gdk.KEY_PRESS_MASK)
         
-        self.w_save_btn = self.xml.get_widget ('_w_save_btn')
-        self.w_save_mnu = self.xml.get_widget ('_w_save_mnu')
-
-        # We manually add a simple search area
-        t = self.uim.get_widget ('/Toolbar')
-        h = gtk.HBox()
-
-        i = gtk.Image()
-        i.set_from_stock(gtk.STOCK_FIND, gtk.ICON_SIZE_LARGE_TOOLBAR)
-        h.pack_start(i, False, False)
-
-        # create a tooltips object
-##      self.toolbartips = gtk.Tooltips()
+        self.w_save_btn = self.xml.get_object('_w_save_btn')
+        self.w_save_mnu = self.xml.get_object('_w_save_mnu')
 
         self.quick_search = gtk.Entry()
+        self.quick_search.set_icon_from_stock(gtk.ENTRY_ICON_PRIMARY, gtk.STOCK_FIND)
         self.quick_search.connect('activate', self.simple_search)
-        h.pack_start(self.quick_search, False, False)
-##      self.toolbartips.set_tip(self.quick_search, _('Quick search'))
 
-        if Config.get ('gnome/tooltips').data:
-            self.quick_search.set_tooltip_text (_('Quick search'))
+        tool_item = gtk.ToolItem()
+        tool_item.add(self.quick_search)
+        toolbar.insert(tool_item, -1)
+
+        tool_item.show_all()
 
-        i = gtk.ToolItem()
-        i.add(h)
-        t.insert(i, -1)
-        
-        i.show_all()
-        
         # The Index list
         self.index = Index.Index (popup = self.uim.get_widget ('/Popup'))
         self.paned.add1 (self.index.w)
@@ -262,7 +253,7 @@ class Document (Connector.Publisher):
         self.paned.add2 (self.display.w)
 
         # Status bar
-        self.statusbar = self.xml.get_widget ('statusbar')
+        self.statusbar = self.xml.get_object('statusbar')
         
         # set window size
         ui_width  = Utils.config.get_int ('/apps/pybliographic/ui/width') or -1
@@ -390,8 +381,8 @@ class Document (Connector.Publisher):
         try:
             file = open (output, 'w')
         except IOError, err:
-            self.w.error (_("can't open file `%s' for writing:\n%s")
-                          % (output, str (err)))
+            Utils.error_dialog_s(_(u"can’t open file “%s” for writing:\n%s")
+                                 % (output, str(err)))
             return
         
         entries = map (lambda x: x.key, self.index.selection ())
@@ -411,7 +402,7 @@ class Document (Connector.Publisher):
             Pyblio.Style.Utils.generate (url, format, self.data, entries, file)
         except RuntimeError, err:
             print err
-            self.w.error (_("Error while parsing `%s':\n%s") % (style, err))
+            Utils.error_dialog_s(_(u"Error while parsing “%s”:\n%s") % (style, err))
         return
 
 
@@ -453,29 +444,25 @@ class Document (Connector.Publisher):
 
         self.actiongroup.get_action ('Save').set_property ('sensitive', self.changed)
 
-        self.statusbar.set_default (text)
-        return
+        self.context_id = self.statusbar.get_context_id('main')
+        self.statusbar.push(self.context_id, text)
 
     
     def confirm (self):
         ''' eventually ask for modification cancellation '''
         
-        if self.changed:
-	    if Config.get('gnome/old-confirmation-dialog').data:
-		return Utils.Callback (_("The database has been modified.\nDiscard changes?"),
-				       self.w).answer ()
-      
-	    else:
-		answer = Utils.Callback (_("The database has been modified.\nSave changes?"),
-				         self.w, cancel_add = True).answer ()
-                if answer == 2:
-                    return False
-                elif answer and self.modification_check ():
-                    self.save_document ()
-                    return True
-		else:
-		    return True
-	return 1
+        if not self.changed:
+            return True
+
+        result = Utils.Callback (_("The database has been modified.\nSave changes?"),
+                                 self.w, cancel_add=True).answer()
+        if result == 2:
+            return False
+        elif result and self.modification_check ():
+            self.save_document ()
+            return True
+        else:
+            return True
 
     def modification_check (self):
 	"""Check for external modification, if necessary,
@@ -516,11 +503,11 @@ class Document (Connector.Publisher):
 
         if url is None:
             # no result.
-            self.w.error (_("Your query returned no result"))
+            Utils.error_dialog_s(_("Your query returned no result"))
             return
         elif url is -1:
             # error
-            self.w.error (_("An error occurred during Medline Query"))
+            Utils.error_dialog_s(_("An error occurred during Medline Query"))
             return
 
         self.open_in_new(url, 'medline', no_name=True)
@@ -530,8 +517,9 @@ class Document (Connector.Publisher):
     def merge_database (self, * arg):
         ''' add all the entries of another database to the current one '''
         # get a new file name
-        (url, how) = FileSelector.URLFileSelection (_("Merge file"),
-                                                    has_auto = True).run ()
+        (url, how) = FileSelector.URLFileSelection(_("Merge file"),
+                                                   has_auto=True,
+                                                   parent=self.w).run ()
 
         if url is None: return
 
@@ -578,7 +566,8 @@ class Document (Connector.Publisher):
         if not self.confirm (): return
 
         # get a new file name
-        (url, how) = FileSelector.URLFileSelection (_("Open file")).run ()
+        (url, how) = FileSelector.URLFileSelection(_("Open file"),
+                                                   parent=self.w).run ()
 
         if url is None: return
         self.open_document (url, how)
@@ -651,7 +640,7 @@ class Document (Connector.Publisher):
                         os.remove (old_auto_save)
                     except (OSError, IOError), error:
                         Utils.set_cursor (self.w, 'normal')
-                        self.w.error (_("Unable to remove autosave file `%s':\n%s") % (str (old_auto_save), str (error)))
+                        Utils.error_dialog_s(_(u"Unable to remove autosave file “%s”:\n%s") % (str (old_auto_save), str (error)))
                         return
 
 
@@ -702,7 +691,7 @@ class Document (Connector.Publisher):
             try:
                 savefile = open (save, 'w')
             except (IOError, OSError), error:
-                self.w.error (_("Error during autosaving:\n%s") % error [1])
+                Utils.error_dialog_s(_("Error during autosaving:\n%s") % error [1])
                 return False
 
             iterator = Selection.Selection (sort = Sort.Sort([Sort.KeySort()]))
@@ -730,7 +719,7 @@ class Document (Connector.Publisher):
                 self.data.update (Sort.Sort([Sort.KeySort()]))
             except (OSError, IOError), error:
                 Utils.set_cursor (self.w, 'normal')
-                self.w.error (_("Unable to save `%s':\n%s") % (str (self.data.key),
+                Utils.error_dialog_s(_(u"Unable to save “%s”:\n%s") % (str (self.data.key),
                                                                str (error)))
                 return
         except:
@@ -738,7 +727,7 @@ class Document (Connector.Publisher):
             traceback.print_exception (etype, value, tb)
             
             Utils.set_cursor (self.w, 'normal')
-            self.w.error (_("An internal error occurred during saving\nTry to Save As..."))
+            Utils.error_dialog_s(_(u"An internal error occurred during saving\nTry to Save As…"))
             return
 
         Utils.set_cursor (self.w, 'normal')
@@ -752,21 +741,23 @@ class Document (Connector.Publisher):
     
     def save_document_as (self, * arg):
         # get a new file name
-        (url, how) = FileSelector.URLFileSelection (
-	    _("Save As..."), has_auto = False, is_save = True).run ()
+        (url, how) = FileSelector.URLFileSelection(_(u"Save As…"),
+                                                   has_auto=False,
+                                                   is_save=True,
+                                                   parent=self.w).run ()
         
         if url is None: return
 
         if os.path.exists (url):
             if not Utils.Callback (
-		_("The file `%s' already exists.\nOverwrite it?")
+		_(u"The file “%s” already exists.\nOverwrite it?")
 		% url, parent = self.w).answer ():
                 return
 
         try:
             file = open (url, 'w')
         except IOError, error:
-            self.w.error (_("During opening:\n%s") % error [1])
+            Utils.error_dialog_s(_("During opening:\n%s") % error [1])
             return
 
         Utils.set_cursor (self.w, 'clock')
@@ -792,7 +783,7 @@ class Document (Connector.Publisher):
                         os.remove (old_auto_save)
                     except (OSError, IOError), error:
                         Utils.set_cursor (self.w, 'normal')
-                        self.w.error (_("Unable to remove autosave file `%s':\n%s") % (str (old_auto_save), str (error)))
+                        Utils.error_dialog_s(_(u"Unable to remove autosave file “%s”:\n%s") % (str (old_auto_save), str (error)))
                         return
 
         
@@ -852,7 +843,7 @@ class Document (Connector.Publisher):
                         os.remove (old_auto_save)
                     except (OSError, IOError), error:
                         Utils.set_cursor (self.w, 'normal')
-                        self.w.error (_("Unable to remove autosave file `%s':\n%s") % (str (old_auto_save), str (error)))
+                        Utils.error_dialog_s(_(u"Unable to remove autosave file “%s”:\n%s") % (str (old_auto_save), str (error)))
                         return
 
         return answer
@@ -877,7 +868,7 @@ class Document (Connector.Publisher):
         for entry in entries:
             
             if self.data.would_have_key (entry.key):
-                if not Utils.Callback (_("An entry called `%s' already exists.\nRename and add it anyway?")
+                if not Utils.Callback (_(u"An entry called “%s” already exists.\nRename and add it anyway?")
                                        % entry.key.key, parent = self.w).answer ():
                     continue
                 
@@ -997,7 +988,7 @@ class Document (Connector.Publisher):
         if l > 1:
             question = _("Remove all the %d entries?") % len (entries)
         else:
-            question = _("Remove entry `%s'?") % entries [0].key.key
+            question = _(u"Remove entry “%s”?") % entries [0].key.key
             
         if not Utils.Callback (question,
                                parent = self.w).answer ():
@@ -1016,7 +1007,7 @@ class Document (Connector.Publisher):
             try:
                 test = SearchCls.AnyTester(q.encode('latin-1'))
             except UnicodeEncodeError:
-                self.w.error (_("your search text must contain\nlatin-1 characters only"))
+                Utils.error_dialog_s(_("your search text must contain\nlatin-1 characters only"))
                 return
         else:
             test = None
@@ -1095,7 +1086,7 @@ class Document (Connector.Publisher):
             try:
                 self.lyx = LyX.LyXClient ()
             except IOError, msg:
-                self.w.error (_("Can't connect to LyX:\n%s") % msg)
+                Utils.error_dialog_s(_(u"Can’t connect to LyX:\n%s") % msg)
                 return
 
         keys = string.join (map (lambda x: x.key.key, entries), ', ')
@@ -1103,7 +1094,7 @@ class Document (Connector.Publisher):
             self.lyx ('citation-insert', keys)
         except IOError, msg:
             msg = msg [1].decode (enc)
-            self.w.error (_("Can't connect to LyX:\n%s") % msg)
+            Utils.error_dialog_s(_(u"Can’t connect to LyX:\n%s") % msg)
         return
     
 
@@ -1153,46 +1144,36 @@ class Document (Connector.Publisher):
 			     str(mergeid), gtk.UI_MANAGER_MENUITEM, False)
 	return
     
-    def key_pressed (self, app, event):
-
+    def key_pressed(self, app, event):
         # filter out special keys
-        
         if event.keyval == gtk.keysyms.Escape:
             # the Esc key restores view to "all entries"
             self.limit_view (None, None)
             self.quick_search.set_text('')
-            
-        if (event.string < 'a' or event.string > 'z') and \
-           (event.string < '0' or event.string > '9'): return False
 
         if self.selection.sort is None:
-            app.flash ("Select a column to search in first.")
+            self.statusbar.push(self.context_id,
+                                _('Select a column to search in first'))
             return False
-        
-        if event.string in printable:
-            # the user searches the first entry in its ordering that starts with this letter
-            if self.incremental_search == '':
-                self.incremental_search = event.string
-                self.incremental_start  = event.time
-            else:
-                if event.time - self.incremental_start > 1000:
-                    self.incremental_search = event.string
-                else:
-                    # two keys in a same shot: we search for the composition of the words
-                    self.incremental_search = self.incremental_search + event.string
-                
-                self.incremental_start  = event.time
 
-            # search first occurrence
-            if self.index.go_to_first (self.incremental_search,
-                                       self.selection.sort.fields [0]):
-                app.flash ("Searching for '%s...'" % self.incremental_search)
-            else:
-                app.flash ("Cannot find '%s...'" % self.incremental_search)
-                
+        search_text = self.quick_search.get_text()
+
+        if event.string not in printable or len(search_text) <= 0:
+            return False
+
+        # search first occurrence
+        if self.index.go_to_first(search_text,
+                                  self.selection.sort.fields[0]):
+            self.statusbar.push(self.context_id,
+                                _(u'Searching for “%s”…') %
+                                search_text)
+        else:
+            self.statusbar.push(self.context_id,
+                                _(u'Cannot find “%s”…') %
+                                search_text)
+
         return False
 
-
     def update_configuration (self):
         ''' save current informations about the program '''
         
@@ -1219,37 +1200,46 @@ class Document (Connector.Publisher):
             gtk.show_uri (None, "help:pybliographer", timestamp)
             
         except gobject.GError, msg:
-            self.w.error (_("Can't display documentation:\n%s") % msg)
+            Utils.error_dialog_s(_(u"Can’t display documentation:\n%s") % msg)
             
         return
     
-    def about (self, *arg):
+    def about(self, *arg):
+        def show_url(dialog, url, user_data):
+            gtk.show_uri(None, url, gtk.gdk.CURRENT_TIME)
 
-	pybliologo = gtk.gdk.pixbuf_new_from_file(
-			os.path.join (version.pybdir, 'pixmaps', 'pybliographic-logo.png'))
-        about = ui.About ('Pybliographic',
-                          version.version,
-                          _("This program is copyrighted under the GNU GPL"),
-                          _("GNOME interface to the Pybliographer system."),
-                          ['Hervé Dréau',
-                           'Frédéric Gobry',
-                           'Zoltán Kóta',
-                           'Travis Oliphant',
-                           'Darrell Rudmann',
-                           'Peter Schulte-Stracke',
-                           'John Vu'],
-                          ['Yuri Bongiorno',
-                           'Frédéric Gobry',
-                           'Zoltán Kóta'],
-                          _('GNOME Translation Team'),
-                          pybliologo)
+        pybliologo = gtk.gdk.pixbuf_new_from_file(
+                        os.path.join (version.pixmapsdir,
+                                      'pybliographic-logo.png'))
+        authors = ['Hervé Dréau',
+                   'Frédéric Gobry',
+                   'Zoltán Kóta',
+                   'Travis Oliphant',
+                   'Darrell Rudmann',
+                   'Peter Schulte-Stracke',
+                   'John Vu',
+                   'Germán Poo-Caamaño']
+        documentors = ['Yuri Bongiorno',
+                       'Frédéric Gobry',
+                       'Zoltán Kóta']
+        translators = _('GNOME Translation Team')
+        license = _("This program is copyrighted under the GNU GPL")
+        comments = _("GNOME interface to the Pybliographer system.")
 
-        about.set_transient_for (self.w)
-        
-        link = ui.HRef ('http://www.pybliographer.org/',
-                        _("Pybliographer Home Page"))
-        link.show ()
-        about.vbox.pack_start (link)
-        about.show()
-        return
+        about = gtk.AboutDialog()
+        about.set_program_name('Pybliographic')
+        about.set_version(version.version)
+        about.set_website('http://www.pybliographer.org/')
+        about.set_website_label(_('Pybliographer Home Page'))
+        about.set_comments(comments)
+        about.set_authors(authors)
+        about.set_translator_credits(translators)
+        about.set_documenters(documentors)
+        about.set_logo(pybliologo)
+        about.set_license(license)
 
+        about.set_transient_for(self.w)
+        gtk.about_dialog_set_url_hook(show_url, None)
+
+        about.run()
+        about.destroy()
