@@ -1,33 +1,39 @@
+# -*- coding: utf-8 -*-
 # This file is part of pybliographer
-# 
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
-# 	   
+#
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.org>
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2 
+# as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-#   
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details. 
-# 
+# GNU General Public License for more details.
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-# 
-# 
+#
+#
 
 # TO FIX
 #   entry editor for more than 50 chars
 # added: Note taking widget
 
-import copy, gobject, gtk, re, string
-from gnome import ui
+import copy
+import re
+import string
+import gobject
+import gtk
 
-from Pyblio import Base, Config, Connector, Exceptions, Fields, Key, Types
-from Pyblio.GnomeUI import Common, Compat, FieldsInfo, FileSelector, Mime, Utils
+from gettext import gettext as _
+
+from Pyblio import Config, Connector, Exceptions, Fields, Key, Types
+from Pyblio.GnomeUI import FieldsInfo, FileSelector, Mime, Utils
 
 key_re = re.compile("^[\w:_+-.()/]+$")
 
@@ -48,7 +54,7 @@ class BaseField(Connector.Publisher):
         self.w = gtk.VBox()
 
         h = gtk.HBox(spacing=5)
-        self.w.pack_start(gtk.Label(field), False, False)
+        self.w.pack_start(gtk.Label(field), False, False, 6)
 
         field = string.lower(field)
         self.field = field
@@ -68,7 +74,7 @@ class BaseField(Connector.Publisher):
         
         h.pack_start(img, False, False)
         
-        self.w.pack_start(h, expand, expand)
+        self.w.pack_start(h, expand, expand, 6)
         self.w.show_all()
 
         flag = 0
@@ -151,7 +157,7 @@ class Entry (TextBase):
 
             self.buff = None
             
-            h.pack_start (self.edit)
+            h.pack_start (self.edit, True, True, 0)
             return 0
 
         w = gtk.ScrolledWindow ()
@@ -170,14 +176,14 @@ class Entry (TextBase):
         w.add (self.edit)
         w.show ()
         
-        h.pack_start (w)
+        h.pack_start (w, True, True, 6)
         return 1
 
 
     def update (self, entry):
         if self.buff:
             text = self.buff.get_text (self.buff.get_start_iter (),
-                                       self.buff.get_end_iter ())
+                                       self.buff.get_end_iter (), False)
             text = string.rstrip (text).encode('latin-1')
         else:
             text = string.rstrip \
@@ -210,13 +216,13 @@ class Text (TextBase):
         w.add (self.edit)
         w.show ()
 
-        h.pack_start (w)
+        h.pack_start (w, True, True, 6)
         return 1
 
 
     def update (self, entry):
         text = self.buff.get_text (self.buff.get_start_iter (),
-                                   self.buff.get_end_iter ())
+                                   self.buff.get_end_iter (), False)
         text = string.rstrip (text).encode ('latin-1')
         
         if text == self.string: return 0
@@ -244,13 +250,13 @@ class AuthorGroup (BaseField):
         w.add (self.edit)
         w.show ()
 
-        h.pack_start (w)
+        h.pack_start(w, True, True, 6)
         return 1
 
 
     def update (self, entry):
         text = self.buff.get_text (self.buff.get_start_iter (),
-                                   self.buff.get_end_iter ())
+                                   self.buff.get_end_iter (), False)
         text = string.strip (text).encode('latin-1')
         
         if text == self.string: return 0
@@ -309,7 +315,7 @@ class Date (BaseField):
         if self.initial [0]:
             self.day.set_text (str (self.initial [0]).decode ('latin-1'))
         hbox.pack_start (self.day)
-        hbox.pack_start (gtk.Label (_("Day")), False, False)
+        hbox.pack_start (gtk.Label (_("Day")), False, False, 3)
         
         self.month = gtk.Entry ()
         self.month.set_size_request (width / 4, height)
@@ -318,7 +324,7 @@ class Date (BaseField):
         if self.initial [1]:
             self.month.set_text (str (self.initial [1]).decode ('latin-1'))
         hbox.pack_start (self.month)
-        hbox.pack_start (gtk.Label (_("Month")), False, False)
+        hbox.pack_start (gtk.Label (_("Month")), False, False, 3)
         
         self.year = gtk.Entry ()
         self.year.set_max_length (4)
@@ -327,10 +333,10 @@ class Date (BaseField):
         if self.initial [2]:
             self.year.set_text (str (self.initial [2]).decode ('latin-1'))
         hbox.pack_start (self.year)
-        hbox.pack_start (gtk.Label (_("Year")), False, False)
+        hbox.pack_start (gtk.Label (_("Year")), False, False, 3)
 
         hbox.show_all ()
-        h.pack_start (hbox)
+        h.pack_start (hbox, True, True, 0)
         return 0
 
 
@@ -352,24 +358,24 @@ class Date (BaseField):
         if text != '':
             try: day = int (text)
             except ValueError:
-                Compat.error_dialog_parented (_("Invalid day field in date"),
-                                                self.day.get_toplevel ())
+                Utils.error_dialog_s(self.day.get_toplevel(),
+                                    ("Invalid day field in date"))
                 return -1
         
         text = string.strip (self.month.get_chars (0, -1)).encode ('latin-1')
         if text != '':
             try: month = int (text)
-            except ValueError, err:
-                Compat.error_dialog_parented (_("Invalid month field in date"),
-                                                self.day.get_toplevel ())
+            except ValueError:
+                Utils.error_dialog_s(self.day.get_toplevel(),
+                                    ("Invalid day field in date"))
                 return -1
         
         text = string.strip (self.year.get_chars (0, -1)).encode ('latin-1')
         if text != '':
             try: year = int (text)
             except ValueError: 
-                Compat.error_dialog_parented (_("Invalid year field in date"),
-                                                self.day.get_toplevel ())
+                Utils.error_dialog_s(self.day.get_toplevel(),
+                                    ("Invalid day field in date"))
                 return -1
         
         if self.initial == (day, month, year): return 0
@@ -381,8 +387,8 @@ class Date (BaseField):
         try:
             entry [self.field] = Fields.Date ((year, month, day))
         except Exceptions.DateError, error:
-            Compat.error_dialog_parented (str (error),
-                                            self.day.get_toplevel ())
+            Utils.error_dialog_s(self.day.get_toplevel(),
+                                 str(error))
             return -1
         return 1
 
@@ -412,14 +418,14 @@ class Reference (BaseField):
         
         self.edit.connect ('drag_data_received', self.drag_received)
         
-        box.pack_start (self.edit, True, True)
-        h.pack_start (box)
+        box.pack_start (self.edit, True, True, 6)
+        h.pack_start (box, True, True, 6)
 
         # A delete button
         button = gtk.Button (_('Delete'), gtk.STOCK_DELETE)
         button.connect ('clicked', self._delete)
         
-        h.pack_start (button, False, False)
+        h.pack_start (button, False, False, 6)
         
         box.show_all ()
         return 0
@@ -498,11 +504,11 @@ class URL (BaseField):
 	self.edit.set_editable (True)
 	self.old_url = self.string.decode ('latin-1')
 	self.edit.set_text (self.old_url)
-	self.box.pack_start (self.edit)
-	self.button = gtk.Button (_('Browse...'))
+	self.box.pack_start (self.edit, True, True, 6)
+	self.button = gtk.Button (_(u'Browse…'))
 	self.button.connect ("clicked", self.cb_clicked)
-	self.box.pack_start (self.button, False)
-	h.pack_start (self.box)
+	self.box.pack_start (self.button, False, True, 6)
+	h.pack_start (self.box, True, True, 6)
         return 0
   
 ##    def update (self, entry):
@@ -589,12 +595,12 @@ class RealEditor (Connector.Publisher):
         self.menu.connect ("changed", self.menu_select)
         
         table.show_all ()
-        self.w.pack_start (table, False, False)
+        self.w.pack_start (table, False, False, 6)
 
         self.newfield_area = gtk.HBox (spacing = 5)
         self.newfield_area.set_border_width (5)
-        self.newfield = ui.Entry ('newfield')
-        
+
+        self.newfield = gtk.Entry()
         self.newfield_area.pack_start (self.newfield)
 
         b = gtk.Button (_("Create Field"))
@@ -615,10 +621,9 @@ class RealEditor (Connector.Publisher):
         
         # Notebook
         self.notebook = gtk.Notebook ()
-        self.notebook.show ()
         self.notebook.connect ('switch-page', self.switch_page_cb)
         
-        self.w.pack_start (self.notebook)
+        self.w.pack_start (self.notebook, True, True, 6)
         self.w.show_all ()
 
         self.lt_init (self.entry, self.fields)
@@ -645,7 +650,6 @@ class RealEditor (Connector.Publisher):
         self.update_notebook ()
         return
 
-
     def apply_cb (self, * args):
         self.issue ('apply')
         return
@@ -761,6 +765,7 @@ class RealEditor (Connector.Publisher):
                          Types.get_field(x).type != Fields.LongText]
                 self.add_type1_widget (label, table, i)
 
+        self.notebook.set_border_width(6)
         self.notebook.show ()
         return
 
@@ -877,14 +882,13 @@ class RealEditor (Connector.Publisher):
     #--------------------------------------------------
     
     def create_field(self, *arg):
-        widget = self.newfield.gtk_entry()
-        text   = string.strip(string.lower(widget.get_text()))
+        text   = string.strip(string.lower(self.newfield.get_text()))
         if not re.match(r"[a-z][\w_-]*$", text):
             if not Utils.Callback(
                 "The fieldname '%s' looks invalid.\nReally proceed?" % text,
                 parent=self.w.get_toplevel()).answer():
                 return
-                
+
         # update the current entry
         current = self.update(self.database, copy.deepcopy(self.entry))
         if current is None:
@@ -893,8 +897,6 @@ class RealEditor (Connector.Publisher):
         newtype = Types.get_field(text).type
         self.entry[text] = newtype(_newcontent[newtype])
         self.update_notebook()
-        return
-    
 
     def update (self, database, entry):
         modified = False
@@ -905,17 +907,17 @@ class RealEditor (Connector.Publisher):
             modified = True
         else:
             if not key_re.match (key):
-                Compat.error_dialog_parented (
-                    _("Invalid key format"), self.w.get_toplevel ())
+                Utils.error_dialog_s(self.w.get_toplevel(),
+                                     _("Invalid key format"))
                 return None
 
             key = Key.Key (database, key)
 
             if key != self.entry.key:
                 if database.has_key (key):
-                     Compat.error_dialog_parented (
-                         _("Key `%s' already exists") % str (key.key),
-                         self.w.get_toplevel ())
+                     Utils.error_dialog_s(
+                         self.w.get_toplevel(),
+                         _(u"Key “%s” already exists") % str (key.key))
                      return None
                 
                 self.entry.key = key
@@ -930,9 +932,10 @@ class RealEditor (Connector.Publisher):
             except UnicodeError:
                 f = Types.get_field(item.field)
                 
-                Compat.error_dialog_parented(
-                    _("The `%s' field contains a non Latin-1 symbol") %
-                    f.name, self.w.get_toplevel())
+                Utils.error_dialog_s(
+                    self.w.get_toplevel(),
+                    _(u"The “%s” field contains a non Latin-1 symbol") %
+                    f.name)
                 return None
             
             if result == -1: return None
@@ -992,9 +995,9 @@ class NativeEditor(Connector.Publisher):
         try:
             text = text.encode('latin-1')
         except UnicodeError:
-            Compat.error_dialog_parented(
-                _("Your text contains non Latin-1 symbols"),
-                self.w.get_toplevel())
+            Utils.error_dialog_s(
+                self.w.get_toplevel(),
+                _("Your text contains non Latin-1 symbols"))
             return None
         try:
             new = self.database.create_native(text)
@@ -1080,8 +1083,7 @@ class Editor(Connector.Publisher):
             'gnome/native-as-default').data and entry.key)
 
         self.toggle_native()
-        self.w.show_all ()
-        return
+        self.w.run ()
 
     def toggle_native(self, *arg):
         self.save_size()
@@ -1154,7 +1156,7 @@ class Editor(Connector.Publisher):
         if self.native_mode:
             return
         n = self.editor.notebook
-        box = n.get_nth_page(n.get_current_page())
+        n.get_nth_page(n.get_current_page())
 
     def save_size(self):
         if not self.editor:
@@ -1209,7 +1211,6 @@ class LT_Widget_1:
                               gtk.POLICY_AUTOMATIC)
         self.display_list (self.entry, self.editor.lt_nodes)
 
-        self.page.set_data ('pyblio-owner', self)
         self.page.show_all()
         self.notebook.insert_page (self.page, self.label, position)
         #list_remove (self.editor.fields, self.keys) 
@@ -1244,7 +1245,7 @@ class LT_Widget_1:
             ebox = gtk.Button()
             ebox.add (vbox)
             ebox.connect ('clicked', self.lt_select_detail, i)
-            content.pack_start(ebox, False, False)
+            content.pack_start(ebox, False, False, 6)
 
         page_child = self.page.get_child()
         if page_child:
@@ -1281,7 +1282,6 @@ class LT_Widget_2:
         self.label = gtk.Label()
         self.page.add(self.content)
         self.content.grab_focus()
-        self.page.set_data ('pyblio-owner', self)
         self.content.set_wrap_mode (gtk.WRAP_WORD)
         self.buff.connect('changed', self.changed_cb)
         self.hidden = True
@@ -1300,7 +1300,7 @@ class LT_Widget_2:
             self.hidden = False
             self.notebook.insert_page (
                 self.page, self.label, self.position)
-        pos = self.notebook.page_num (self.page)
+        self.notebook.page_num (self.page)
         self.notebook.set_current_page (self.position)
 
     def update (self):
@@ -1355,7 +1355,7 @@ class  LT_Dialog_1     :
         
         self.options = gtk.combo_box_new_text ()
 
-        self.dialog.vbox.pack_start (self.options, True, True, 12)
+        self.dialog.vbox.pack_start (self.options, True, True, 6)
         self.fields = [ x for x in Config.get ('base/fields').data
                         if Types.get_field(x).type == Fields.LongText]
         self.fields.sort()
