@@ -1,7 +1,9 @@
+# -*- coding: utf-8 -*-
+#
 # This file is part of pybliographer
 #
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.or
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,17 +32,19 @@
 
 ''' Main index containing the columned view of the entries '''
 
+import os.path
+import cPickle
+import gobject
+import gtk
+import gtk.gdk
+import pango
+
+from string import ascii_letters, lower, join, digits
+
 from Pyblio import Config, Connector, Fields, Resource
 from Pyblio import Types, Sort, userformat, version
+from Pyblio.GnomeUI import Mime, Utils
 
-from gnome import ui
-import gobject, gtk, gtk.gdk, os.path, pango
-
-from Pyblio.GnomeUI import FieldsInfo, Mime, Utils
-
-from string import *
-
-import cPickle
 
 pickle = cPickle
 del cPickle
@@ -51,6 +55,7 @@ for c in ascii_letters + digits:
 
 _safechar = ''.join (_safechar)
 
+
 class Index (Connector.Publisher):
     ''' Graphical index of an iterator '''
 
@@ -72,7 +77,7 @@ class Index (Connector.Publisher):
 
         i = 0
         self.gvpixbuf = gtk.gdk.pixbuf_new_from_file(
-            os.path.join (version.pybdir, 'pixmaps', 'pybliographic-viewer.png'))
+            os.path.join (version.pixmapsdir, 'pybliographic-viewer.png'))
         if True:
             rend = gtk.CellRendererPixbuf ()
             col = gtk.TreeViewColumn ('P', rend, pixbuf = len(fields))
