@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998-2004 Frederic GOBRY
-# Email : gobry@pybliographer.org
+# Copyright (C) 2018 Germán Poo-Caamaño <gpoo@gnome.org>
+# Copyright (C) 1998-2004 Frederic GOBRY <gobry@pybliographer.org>
 # 	   
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,16 +23,12 @@
 ''' Utility functions for Gnome Interface management. '''
 
 import os
-
 import gtk, pango
-import gtk.glade
-
-from gnome import ui
-
-from Pyblio import Config, version
-
 import gconf
 
+from gettext import gettext as _
+
+
 class Callback:
 
     ''' This class provides a simple requested that asks the user a
@@ -65,8 +62,8 @@ class Callback:
 
 glade_root = os.path.join(os.path.dirname(__file__), 'glade')
 
-class GladeWindow:
 
+class Builder:
     ''' A Helper class that builds a graphical interface provided by a
     Glade XML file. This class binds the methods with
     signal_autoconnect, and imports widgets whose name starts with _w_
@@ -84,53 +81,52 @@ class GladeWindow:
 
     '''
 
-
     # This is a class variable that contains the file name to load for
     # each instance of a subclass.
-
     gladeinfo = { 'file': None,
                   'root': None,
                   'name': None
                   }
 
-    def __init__ (self, parent = None, window = None):
-        
-        gp = os.path.join(glade_root, self.gladeinfo ['file'])
-        self.xml = gtk.glade.XML (gp, window, domain = "pybliographer")
-        self.xml.signal_autoconnect (self)
+    def __init__(self, parent=None, window=None):
 
-        for w in self.xml.get_widget_prefix ('_w_'):
-            setattr (self, w.name, w)
+        fname = os.path.join(glade_root, self.gladeinfo['file'])
+        self.xml = gtk.Builder()
+        self.xml.set_translation_domain('pybliographer')
+        self.xml.add_from_file(fname)
+        self.xml.connect_signals(self)
+
+        for w in self.xml.get_objects():
+            if isinstance(w, gtk.Buildable):
+                name = gtk.Buildable.get_name(w)
+                if name.startswith('_w_'):
+                    setattr(self, name, w)
 
         # Set the parent window. The root widget is not necessarily
         # exported as an instance attribute.
-        root = self.xml.get_widget (self.gladeinfo ['root'])
-        cfg  = '/apps/pybliographic/%s/' % self.gladeinfo ['name']
-        
-        w = config.get_int (cfg + 'width')  or -1
-        h = config.get_int (cfg + 'height') or -1
+        root = self.xml.get_object(self.gladeinfo['root'])
+        cfg  = '/apps/pybliographic/%s/' % self.gladeinfo['name']
+
+        w = config.get_int(cfg + 'width') or -1
+        h = config.get_int(cfg + 'height') or -1
 
         if w != -1 and h != -1:
-            root.set_default_size (w, h)
-            root.resize (w, h)
-        
+            root.set_default_size(w, h)
+            root.resize(w, h)
+
         if parent:
-            root.set_transient_for (parent)
-            
-        return
+            root.set_transient_for(parent)
 
     def size_save (self):
-        root = self.xml.get_widget (self.gladeinfo ['root'])
-        cfg  = '/apps/pybliographic/%s/' % self.gladeinfo ['name']
+        root = self.xml.get_object(self.gladeinfo['root'])
+        cfg  = '/apps/pybliographic/%s/' % self.gladeinfo['name']
 
-        w, h = root.get_size ()
+        w, h = root.get_size()
 
         config.set_int (cfg + 'width',  w)
         config.set_int (cfg + 'height', h)
 
-        return
-    
-    
+
 config = gconf.client_get_default ()
 
 cursor = {
@@ -151,20 +147,6 @@ def set_cursor (self, name):
     return
 
 
-##_tooltips = gtk.Tooltips ()
-
-
-##def set_tip (w, text):
-##    _tooltips.set_tip (w, text)
-##    return
-
-
-##if Config.get ('gnome/tooltips').data:
-##    _tooltips.enable ()
-##else:
-##    _tooltips.disable ()
-
-
 def popup_add (menu, item, action = None, argument = None):
     ''' Helper to add a new menu entry '''
     
@@ -177,44 +159,57 @@ def popup_add (menu, item, action = None, argument = None):
     
     return tmp
 
-def error_dialog (title, err, parent = None):
+def error_dialog(title, err, parent=None):
 
-    dialog = \
-           gtk.MessageDialog (parent,
-                              gtk.DIALOG_MODAL |
-                              gtk.DIALOG_DESTROY_WITH_PARENT,
-                              gtk.MESSAGE_ERROR,
-                              message_format = title)
+    dialog = gtk.MessageDialog(parent,
+                               gtk.DIALOG_MODAL |
+                               gtk.DIALOG_DESTROY_WITH_PARENT,
+                               gtk.MESSAGE_ERROR,
+                               gtk.BUTTONS_CLOSE,
+                               title)
+    dialog.format_secondary_text(_("The following errors occurred:"))
 
-    b = dialog.add_button (gtk.STOCK_OK, gtk.RESPONSE_OK)
-    b.set_property ('has_default', True)
-    
     buff = gtk.TextBuffer ()
-    title = buff.create_tag ('title', weight = pango.WEIGHT_BOLD)
+    iter = buff.get_start_iter()
+    buff.insert(iter, str(err))
 
-    text = gtk.TextView ()
-    text.set_editable (False)
-    text.set_cursor_visible (False)
-    text.set_buffer (buff)
-    text.set_size_request (400, 200)
+    text = gtk.TextView()
+    text.set_editable(False)
+    text.set_cursor_visible(False)
+    text.set_size_request(400, 200)
+    text.set_buffer(buff)
 
-    iter = buff.get_start_iter ()
-    
-    buff.insert_with_tags (iter, _("The following errors occurred:\n"),
-                           title)
-    
-    buff.insert (iter, str (err))
-    
-    holder = gtk.ScrolledWindow ()
-    holder.set_policy (gtk.POLICY_AUTOMATIC,
-                       gtk.POLICY_AUTOMATIC)
-    holder.add (text)
-    
-    dialog.vbox.pack_start (holder)
-    holder.show_all ()
-    
-    dialog.run ()
-    dialog.destroy ()
-    
-    return
+    holder = gtk.ScrolledWindow()
+    holder.set_policy(gtk.POLICY_AUTOMATIC,
+                      gtk.POLICY_AUTOMATIC)
+    holder.set_property('expand', True)
+    holder.add(text)
 
+    dialog.vbox.pack_start(holder, False, False, 0)
+    dialog.vbox.set_property('spacing', 0)
+    dialog.show_all ()
+
+    dialog.run()
+    dialog.destroy()
+
+
+def error_dialog_s(parent, primary, secondary=None):
+    dialog = gtk.MessageDialog(parent,
+                               gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                               gtk.MESSAGE_ERROR,
+                               gtk.BUTTONS_CLOSE, primary)
+    if secondary:
+        dialog.format_secondary_text(secondary)
+    dialog.run()
+    dialog.destroy()
+
+
+def warning_dialog_s(parent, primary, secondary=None):
+    dialog = gtk.MessageDialog(parent,
+                               gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                               gtk.MESSAGE_WARNING,
+                               gtk.BUTTONS_CLOSE, primary)
+    if secondary:
+        dialog.format_secondary_text(secondary)
+    dialog.run()
+    dialog.destroy()
