@@ -1,13 +1,7 @@
 # Site configuration
-
+import os
 from Pyblio import Autoload, Config, version
 
-from Pyblio.TextUI import *
-
-# ==================================================
-
-import string, os
-
 # define autoloaded formats
 
 Autoload.preregister ('format', 'BibTeX',  'Pyblio.Format.BibTeX',  '.*\.bib')
